==> tool-sql-2.6.0-pre-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralBooleanImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.instanceloading.AttributeChangedDelta;
import io.ciera.runtime.instanceloading.InstanceCreatedDelta;
import io.ciera.runtime.summit.application.IRunContext;
import io.ciera.runtime.summit.classes.IInstanceIdentifier;
import io.ciera.runtime.summit.classes.InstanceIdentifier;
import io.ciera.runtime.summit.classes.ModelInstance;
import io.ciera.runtime.summit.exceptions.EmptyInstanceException;
import io.ciera.runtime.summit.exceptions.InstancePopulationException;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.IWhere;
import io.ciera.runtime.summit.types.IXtumlType;
import io.ciera.runtime.summit.types.StringUtil;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.ooaofooa.value.LiteralBoolean;
import io.ciera.tool.sql.ooaofooa.value.Value;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueImpl;


public class LiteralBooleanImpl extends ModelInstance<LiteralBoolean,Sql> implements LiteralBoolean {

    public static final String KEY_LETTERS = "V_LBO";
    public static final LiteralBoolean EMPTY_LITERALBOOLEAN = new EmptyLiteralBoolean();

    private Sql context;

    // constructors
    private LiteralBooleanImpl( Sql context ) {
        this.context = context;
        ref_Value_ID = UniqueId.random();
        m_Value = "";
        R801_is_a_Value_inst = ValueImpl.EMPTY_VALUE;
    }

    private LiteralBooleanImpl( Sql context, UniqueId instanceId, UniqueId ref_Value_ID, String m_Value ) {
        super(instanceId);
        this.context = context;
        this.ref_Value_ID = ref_Value_ID;
        this.m_Value = m_Value;
        R801_is_a_Value_inst = ValueImpl.EMPTY_VALUE;
    }

    public static LiteralBoolean create( Sql context ) throws XtumlException {
        LiteralBoolean newLiteralBoolean = new LiteralBooleanImpl( context );
        if ( context.addInstance( newLiteralBoolean ) ) {
            newLiteralBoolean.getRunContext().addChange(new InstanceCreatedDelta(newLiteralBoolean, KEY_LETTERS));
            return newLiteralBoolean;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }

    public static LiteralBoolean create( Sql context, UniqueId instanceId, UniqueId ref_Value_ID, String m_Value ) throws XtumlException {
        LiteralBoolean newLiteralBoolean = new LiteralBooleanImpl( context, instanceId, ref_Value_ID, m_Value );
        if ( context.addInstance( newLiteralBoolean ) ) {
            return newLiteralBoolean;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }



    // attributes
    private UniqueId ref_Value_ID;
    @Override
    public void setValue_ID(UniqueId ref_Value_ID) throws XtumlException {
        checkLiving();
        if (ref_Value_ID.inequality( this.ref_Value_ID)) {
            final UniqueId oldValue = this.ref_Value_ID;
            this.ref_Value_ID = ref_Value_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Value_ID", oldValue, this.ref_Value_ID));
        }
    }
    @Override
    public UniqueId getValue_ID() throws XtumlException {
        checkLiving();
        return ref_Value_ID;
    }
    private String m_Value;
    @Override
    public void setValue(String m_Value) throws XtumlException {
        checkLiving();
        if (StringUtil.inequality(m_Value, this.m_Value)) {
            final String oldValue = this.m_Value;
            this.m_Value = m_Value;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "m_Value", oldValue, this.m_Value));
        }
    }
    @Override
    public String getValue() throws XtumlException {
        checkLiving();
        return m_Value;
    }


    // instance identifiers
    @Override
    public IInstanceIdentifier getId1() {
        try {
            return new InstanceIdentifier(getValue_ID());
        }
        catch ( XtumlException e ) {
            getRunContext().getLog().error(e);
            System.exit(1);
            return null;
        }
    }

    // operations


    // static operations


    // events


    // selections
    private Value R801_is_a_Value_inst;
    @Override
    public void setR801_is_a_Value( Value inst ) {
        R801_is_a_Value_inst = inst;
    }
    @Override
    public Value R801_is_a_Value() throws XtumlException {
        return R801_is_a_Value_inst;
    }


    @Override
    public IRunContext getRunContext() {
        return context().getRunContext();
    }

    @Override
    public Sql context() {
        return context;
    }

    @Override
    public String getKeyLetters() {
        return KEY_LETTERS;
    }

    @Override
    public LiteralBoolean self() {
        return this;
    }

    @Override
    public LiteralBoolean oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        if (condition.evaluate(this)) return this;
        else return EMPTY_LITERALBOOLEAN;
    }

}

class EmptyLiteralBoolean extends ModelInstance<LiteralBoolean,Sql> implements LiteralBoolean {

    // attributes
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public UniqueId getValue_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setValue( String m_Value ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public String getValue() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }


    // operations


    // selections
    @Override
    public Value R801_is_a_Value() {
        return ValueImpl.EMPTY_VALUE;
    }


    @Override
    public String getKeyLetters() {
        return LiteralBooleanImpl.KEY_LETTERS;
    }

    @Override
    public LiteralBoolean self() {
        return this;
    }

    @Override
    public boolean isEmpty() {
        return true;
    }

    @Override
    public LiteralBoolean oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        return LiteralBooleanImpl.EMPTY_LITERALBOOLEAN;
    }

}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/LiteralBooleanImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.instanceloading.AttributeChangedDelta;
import io.ciera.runtime.instanceloading.InstanceCreatedDelta;
import io.ciera.runtime.summit.application.IRunContext;
import io.ciera.runtime.summit.classes.IInstanceIdentifier;
import io.ciera.runtime.summit.classes.InstanceIdentifier;
import io.ciera.runtime.summit.classes.ModelInstance;
import io.ciera.runtime.summit.exceptions.EmptyInstanceException;
import io.ciera.runtime.summit.exceptions.InstancePopulationException;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.IWhere;
import io.ciera.runtime.summit.types.IXtumlType;
import io.ciera.runtime.summit.types.StringUtil;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.Sql;
import io.ciera.tool.sql.ooaofooa.value.LiteralBoolean;
import io.ciera.tool.sql.ooaofooa.value.Value;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueImpl;


public class LiteralBooleanImpl extends ModelInstance<LiteralBoolean,Sql> implements LiteralBoolean {

    public static final String KEY_LETTERS = "V_LBO";
    public static final LiteralBoolean EMPTY_LITERALBOOLEAN = new EmptyLiteralBoolean();

    private Sql context;

    // constructors
    private LiteralBooleanImpl( Sql context ) {
        this.context = context;
        ref_Value_ID = UniqueId.random();
        m_Value = "";
        R801_is_a_Value_inst = ValueImpl.EMPTY_VALUE;
    }

    private LiteralBooleanImpl( Sql context, UniqueId instanceId, UniqueId ref_Value_ID, String m_Value ) {
        super(instanceId);
        this.context = context;
        this.ref_Value_ID = ref_Value_ID;
        this.m_Value = m_Value;
        R801_is_a_Value_inst = ValueImpl.EMPTY_VALUE;
    }

    public static LiteralBoolean create( Sql context ) throws XtumlException {
        LiteralBoolean newLiteralBoolean = new LiteralBooleanImpl( context );
        if ( context.addInstance( newLiteralBoolean ) ) {
            newLiteralBoolean.getRunContext().addChange(new InstanceCreatedDelta(newLiteralBoolean, KEY_LETTERS));
            return newLiteralBoolean;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }

    public static LiteralBoolean create( Sql context, UniqueId ref_Value_ID, String m_Value ) throws XtumlException {
        return create(context, UniqueId.random(), ref_Value_ID, m_Value);
    }

    public static LiteralBoolean create( Sql context, UniqueId instanceId, UniqueId ref_Value_ID, String m_Value ) throws XtumlException {
        LiteralBoolean newLiteralBoolean = new LiteralBooleanImpl( context, instanceId, ref_Value_ID, m_Value );
        if ( context.addInstance( newLiteralBoolean ) ) {
            return newLiteralBoolean;
        }
        else throw new InstancePopulationException( "Instance already exists within this population." );
    }



    // attributes
    private UniqueId ref_Value_ID;
    @Override
    public void setValue_ID(UniqueId ref_Value_ID) throws XtumlException {
        checkLiving();
        if (ref_Value_ID.inequality( this.ref_Value_ID)) {
            final UniqueId oldValue = this.ref_Value_ID;
            this.ref_Value_ID = ref_Value_ID;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "ref_Value_ID", oldValue, this.ref_Value_ID));
        }
    }
    @Override
    public UniqueId getValue_ID() throws XtumlException {
        checkLiving();
        return ref_Value_ID;
    }
    private String m_Value;
    @Override
    public String getValue() throws XtumlException {
        checkLiving();
        return m_Value;
    }
    @Override
    public void setValue(String m_Value) throws XtumlException {
        checkLiving();
        if (StringUtil.inequality(m_Value, this.m_Value)) {
            final String oldValue = this.m_Value;
            this.m_Value = m_Value;
            getRunContext().addChange(new AttributeChangedDelta(this, KEY_LETTERS, "m_Value", oldValue, this.m_Value));
        }
    }


    // instance identifiers
    @Override
    public IInstanceIdentifier getId1() {
        try {
            return new InstanceIdentifier(getValue_ID());
        }
        catch ( XtumlException e ) {
            getRunContext().getLog().error(e);
            System.exit(1);
            return null;
        }
    }

    // operations


    // static operations


    // events


    // selections
    private Value R801_is_a_Value_inst;
    @Override
    public void setR801_is_a_Value( Value inst ) {
        R801_is_a_Value_inst = inst;
    }
    @Override
    public Value R801_is_a_Value() throws XtumlException {
        return R801_is_a_Value_inst;
    }


    @Override
    public IRunContext getRunContext() {
        return context().getRunContext();
    }

    @Override
    public Sql context() {
        return context;
    }

    @Override
    public String getKeyLetters() {
        return KEY_LETTERS;
    }

    @Override
    public LiteralBoolean self() {
        return this;
    }

    @Override
    public LiteralBoolean oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        if (condition.evaluate(this)) return this;
        else return EMPTY_LITERALBOOLEAN;
    }

}

class EmptyLiteralBoolean extends ModelInstance<LiteralBoolean,Sql> implements LiteralBoolean {

    // attributes
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }
    public UniqueId getValue_ID() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public String getValue() throws XtumlException {
        throw new EmptyInstanceException( "Cannot get attribute of empty instance." );
    }
    public void setValue( String m_Value ) throws XtumlException {
        throw new EmptyInstanceException( "Cannot set attribute of empty instance." );
    }


    // operations


    // selections
    @Override
    public Value R801_is_a_Value() {
        return ValueImpl.EMPTY_VALUE;
    }


    @Override
    public String getKeyLetters() {
        return LiteralBooleanImpl.KEY_LETTERS;
    }

    @Override
    public LiteralBoolean self() {
        return this;
    }

    @Override
    public boolean isEmpty() {
        return true;
    }

    @Override
    public LiteralBoolean oneWhere(IWhere<IXtumlType> condition) throws XtumlException {
        if (null == condition) throw new XtumlException("Null condition passed to selection.");
        return LiteralBooleanImpl.EMPTY_LITERALBOOLEAN;
    }

}
